Reference Manual
================

The documentation may be a little messy for the moment, it will get better with time.

.. toctree::
   :maxdepth: 2

   Clip
   VideoClip
   videofx
   videotools
   AudioClip
   audiofx
   audiotools
   ffmpeg
   decorators

